@@ -9,14 +9,14 @@
 
   PROGRAMMERS:
 
-    martin.isenburg@rapidlasso.com  -  http://rapidlasso.com
+    info@rapidlasso.de  -  https://rapidlasso.de
 
   COPYRIGHT:
 
-    (c) 2007-2017, martin isenburg, rapidlasso - fast tools to catch reality
+    (c) 2007-2022, rapidlasso GmbH - fast tools to catch reality
 
     This is free software; you can redistribute and/or modify it under the
-    terms of the GNU Lesser General Licence as published by the Free Software
+    terms of the Apache Public License 2.0 published by the Apache Software
     Foundation. See the COPYING file for more information.
 
     This software is distributed WITHOUT ANY WARRANTY and without even the
@@ -251,7 +251,7 @@ typedef struct laszip_point
 #define laszip_DECOMPRESS_SELECTIVE_BYTE5              0x00200000
 #define laszip_DECOMPRESS_SELECTIVE_BYTE6              0x00400000
 #define laszip_DECOMPRESS_SELECTIVE_BYTE7              0x00800000
-#define laszip_DECOMPRESS_SELECTIVE_EXTRA_BYTES        0xFFF00000
+#define laszip_DECOMPRESS_SELECTIVE_EXTRA_BYTES        0xFFFF0000
 
 /*---------------------------------------------------------------------------*/
 /*---------------- DLL functions to manage the LASzip DLL -------------------*/
